@@ -67,7 +67,7 @@ remote <- function(func, args = list()) {
   extraopts <- c("Ncpus", "BioC_mirror")
   pkg_options <- opts[grepl("^pkg[.]", names(opts)) | names(opts) %in% extraopts]
   envs <- Sys.getenv()
-  extraenvs <- "R_BIOC_VERSION"
+  extraenvs <- c("R_BIOC_VERSION", "PATH")
   pkg_envs <- envs[grepl("^PKG_", names(envs)) | names(envs) %in% extraenvs]
   rs$run(function(new_opts, new_envs) {
     opts <- options()
@@ -115,11 +115,11 @@ remote <- function(func, args = list()) {
     # This is a temporary workaround until we have a principled way of
     # printing the various error types in the main process.
     if (inherits(res$error$parent, "package_build_error") &&
-      !is.null(res$error$parent$data$stdout)) {
+      !is.null(res$error$parent$stdout)) {
       res$error$parent$message <- paste0(
         res$error$parent$message,
         "\nFull installation output:\n",
-        paste(res$error$parent$data$stdout, collapse = "\n")
+        paste(res$error$parent$stdout, collapse = "\n")
       )
     }
     err$throw(res$error)
